==> kImageAnnotator-0.4.1.tar.gz: kImageAnnotator-0.4.1/translations/kImageAnnotator_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Aranżacja</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Przesuń na wierzch</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Przesuń do przodu</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Przesuń do tyłu</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Przesuń na spód</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Wybierz to</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Kolor tekstu</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Rozmiar czcionki</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Numer początkowy</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Współczynnik zaciemniania</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zamknij Inne</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zamknij wszystko</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Zamknij wszystko po lewej stronie</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Zamknij wszystkie po prawej stronie</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Kadruj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Widoczność krawędzi i wypełnienia</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Obramowanie i wypełnienie</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Obramowanie i brak wypełnienia</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Bez obramowania i bez wypełnienia</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efekty obrazu</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Bez efektu</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Cień</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Skala szarości</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Obramowanie</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skaluj obraz</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Zachowaj proporcje</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Szerokość:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pikseli</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Naklejka</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Wybierz</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pióro</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Znacznik prostokątny</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Znacznik eliptyczny</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Zakreślacz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Podwójna strzałka</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Rozmycie</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Wskaźnik numeryczny</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Naklejka</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pikslowanie</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Wskaźnik tekstu</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Strzałka tekstu</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Strzałka numeryczna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation>Poziom powiększenia</translation>
    </message>
</context>
</TS>

==> kImageAnnotator-0.6.1.tar.gz: kImageAnnotator-0.6.1/translations/kImageAnnotator_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Aranżacja</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Przesuń na wierzch</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Przesuń do przodu</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Przesuń do tyłu</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Przesuń na spód</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Wybierz to</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Ustawienia główne</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Ustawienia obrazu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Kolor tekstu</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Numer ziarna</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Współczynnik zaciemniania</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Cień elementu</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Ustawienia elementów</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zamknij Inne</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zamknij wszystko</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Zamknij wszystko po lewej stronie</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Zamknij wszystkie po prawej stronie</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Wybór narzędzia</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Włączone</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Obróć</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Pionowo</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Poziomo</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Zastosuj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anuluj</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Widoczność krawędzi i wypełnienia</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Obramowanie i wypełnienie</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Obramowanie i brak wypełnienia</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Bez obramowania i bez wypełnienia</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Rozmiar czcionki</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Pochylenie</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efekty obrazu</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Bez efektu</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Cień</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Skala szarości</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Obramowanie</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Odwróć kolor</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Ograniczone</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Po włączeniu wymusza kanwę,
aby uwzględnić obraz tła.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kolor:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Kolor tła płótna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Obróć obraz</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° zgodnie z ruchem wskazówek zegara</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° przeciwnie do ruchu wskazówek zegara</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Dowolnie</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Wartości dodatnie obracają zgodnie z ruchem wskazówek zegara, wartości ujemne przeciwnie do ruchu wskazówek zegara.
Obracanie przez mnożniki inne niż 90° może spowodować utratę jakości.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Poziomo</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Pionowo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Obróć</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Przerzut</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skaluj obraz</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Zachowaj proporcje</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Szerokość:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pikseli</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Naklejka</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Wybierz</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pióro</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Znacznik prostokątny</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Znacznik eliptyczny</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Zakreślacz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Podwójna strzałka</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Rozmycie</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Wskaźnik numeryczny</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Naklejka</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pikslowanie</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Wskaźnik tekstu</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Strzałka tekstu</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Strzałka numeryczna</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Zduplikowane</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Powiększ (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Pomniejsz (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Resetuj powiększenie (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
